@@ -31,6 +31,7 @@ command_index = {
     ('erc20', 'balances'): 'ctc.cli.commands.data.erc20.balances_command',
     ('erc20', 'transfers'): 'ctc.cli.commands.data.erc20.transfers_command',
     ('events',): 'ctc.cli.commands.data.events_command',
+    ('find',): 'ctc.cli.commands.data.find_command',
     ('gas',): 'ctc.cli.commands.data.gas_command',
     ('transaction',): 'ctc.cli.commands.data.transaction_command',
     #
@@ -40,9 +41,13 @@ command_index = {
     ('ens', 'exists'): 'ctc.protocols.ens_utils.cli.ens.exists_command',
     ('ens', 'hash'): 'ctc.protocols.ens_utils.cli.ens.hash_command',
     ('ens', 'owner'): 'ctc.protocols.ens_utils.cli.ens.owner_command',
+    ('ens', 'records'): 'ctc.protocols.ens_utils.cli.ens.records_command',
     ('ens', 'resolve'): 'ctc.protocols.ens_utils.cli.ens.resolve_command',
     ('ens', 'reverse'): 'ctc.protocols.ens_utils.cli.ens.reverse_command',
-    ('fei', 'payload'): 'ctc.protocols.fei_utils.cli.fei.payload_command',
+    ('fei', 'analytics'): 'ctc.protocols.fei_utils.cli.fei.analytics_command',
+    ('fei', 'pcv'): 'ctc.protocols.fei_utils.cli.fei.pcv_command',
+    ('fei', 'pcv', 'assets'): 'ctc.protocols.fei_utils.cli.fei.pcv_assets_command',
+    ('fei', 'pcv', 'deposits'): 'ctc.protocols.fei_utils.cli.fei.pcv_deposits_command',
     ('rari', 'fuse'): 'ctc.protocols.rari_utils.cli.rari.fuse_command',
     ('uniswap', 'mints'): 'ctc.protocols.uniswap_v2_utils.cli.mints_command',
     ('uniswap', 'burns'): 'ctc.protocols.uniswap_v2_utils.cli.burns_command',
